Materials
=========

.. currentmodule:: scarabee

.. autoclass:: scarabee.CrossSection

.. autoclass:: scarabee.DiffusionCrossSection

.. autoclass:: scarabee.ADF
   :members:

.. autoclass:: scarabee.CDF
   :members:

.. autoclass:: scarabee.DiffusionData

.. autoclass:: scarabee.NuclideHandle
   :members:

.. autoclass:: scarabee.NDLibrary

.. autoclass:: scarabee.MicroDepletionXS
   :members:

.. autoclass:: scarabee.MicroNuclideXS
   :members:

.. autoclass:: scarabee.ResonantOneGroupXS
   :members:

.. autoclass:: scarabee.DepletionReactionRates
   :members:

.. autoclass:: scarabee.Nuclide
   :members:

.. autoclass:: scarabee.Fraction
   :members:

.. autoclass:: scarabee.MaterialComposition

.. autoclass:: scarabee.DensityUnits
   :members:

.. autoclass:: scarabee.Material

.. autofunction:: scarabee.borated_water

.. autofunction:: scarabee.water_density

.. autoclass:: scarabee.MixingFraction
   :members:

.. autofunction:: scarabee.mix_materials

.. autoclass:: scarabee.FluxCalculator
